Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/marian-nmt/marian-regression-tests.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGraeme Nail <graemenail.work@gmail.com>2022-06-03 17:09:21 +0300
committerGraeme Nail <graemenail.work@gmail.com>2022-06-03 17:09:21 +0300
commitefa0fd80c130faeb16fe4ea348122e31f10ffc4e (patch)
tree3bd1072f5381c3633543ded3d8a519ebf8dccb4b
parent4fa9ff55af68bc87d8bd04c9b410f1e1d3874718 (diff)
Rename CPU flag from MRT_MARIAN_USE_MKL to MRT_MARIAN_USE_CPUusecpu
-rwxr-xr-xrun_mrt.sh4
-rw-r--r--tests/decoder/align/test_align_cpu.sh4
-rw-r--r--tests/decoder/intgemm/_test_intgemm_16bit.sh2
-rw-r--r--tests/decoder/intgemm/_test_intgemm_8bit.sh2
-rw-r--r--tests/decoder/intgemm/_test_intgemm_8bit_shifted.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_16bit.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_16bit_avx2.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_16bit_sse2.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_8bit.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_8bit_avx2.sh2
-rw-r--r--tests/decoder/intgemm/test_intgemm_8bit_ssse3.sh2
-rw-r--r--tests/decoder/wmt16/test_ende_cpu.sh4
-rw-r--r--tests/models/transformer/test_hard_aligns_cpu.sh4
-rw-r--r--tests/models/wnmt18/test_student_small.sh4
-rw-r--r--tests/models/wnmt18/test_student_small_aan.sh4
-rw-r--r--tests/models/wnmt18/test_student_small_aan_intgemm16.sh4
-rw-r--r--tests/models/wnmt18/test_student_small_aan_intgemm8.sh4
-rw-r--r--tests/scorer/scores/test_scores_cpu.sh4
-rw-r--r--tests/server/test_ende_cpu.sh4
-rw-r--r--tests/training/restoring/multi-gpu/test_adam_sync_cpu.sh4
20 files changed, 31 insertions, 31 deletions
diff --git a/run_mrt.sh b/run_mrt.sh
index 3716d49..576b42f 100755
--- a/run_mrt.sh
+++ b/run_mrt.sh
@@ -109,7 +109,7 @@ fi
# Check Marian compilation settings
export MRT_MARIAN_BUILD_TYPE=$(cat $MRT_ROOT/cmake.log | grep -i "CMAKE_BUILD_TYPE=" | cut -f2 -d=)
export MRT_MARIAN_COMPILER=$(cat $MRT_ROOT/cmake.log | grep -i "CMAKE_CXX_COMPILER=" | cut -f2 -d=)
-export MRT_MARIAN_USE_MKL=$(cat $MRT_ROOT/cmake.log | egrep -i "COMPILE_CPU=(true|on|1)" | cat)
+export MRT_MARIAN_USE_CPU=$(cat $MRT_ROOT/cmake.log | egrep -i "COMPILE_CPU=(true|on|1)" | cat)
export MRT_MARIAN_USE_CUDA=$(cat $MRT_ROOT/cmake.log | egrep -i "COMPILE_CUDA=(true|on|1)" | cat)
export MRT_MARIAN_USE_CUDNN=$(cat $MRT_ROOT/cmake.log | egrep -i "USE_CUDNN=(true|on|1)" | cat)
export MRT_MARIAN_USE_SENTENCEPIECE=$(cat $MRT_ROOT/cmake.log | egrep -i "USE_SENTENCEPIECE=(true|on|1)" | cat)
@@ -118,7 +118,7 @@ export MRT_MARIAN_USE_UNITTESTS=$(cat $MRT_ROOT/cmake.log | egrep -i "COMPIL
log "Build type: $MRT_MARIAN_BUILD_TYPE"
log "Using compiler: $MRT_MARIAN_COMPILER"
-log "Using MKL: $MRT_MARIAN_USE_MKL"
+log "Using CPU: $MRT_MARIAN_USE_CPU"
log "Using CUDNN: $MRT_MARIAN_USE_CUDNN"
log "Using SentencePiece: $MRT_MARIAN_USE_SENTENCEPIECE"
log "Using FBGEMM: $MRT_MARIAN_USE_FBGEMM"
diff --git a/tests/decoder/intgemm/_test_intgemm_16bit.sh b/tests/decoder/intgemm/_test_intgemm_16bit.sh
index cc10e7f..9bdba6d 100644
--- a/tests/decoder/intgemm/_test_intgemm_16bit.sh
+++ b/tests/decoder/intgemm/_test_intgemm_16bit.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/_test_intgemm_8bit.sh b/tests/decoder/intgemm/_test_intgemm_8bit.sh
index a2684ca..6767aea 100644
--- a/tests/decoder/intgemm/_test_intgemm_8bit.sh
+++ b/tests/decoder/intgemm/_test_intgemm_8bit.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/_test_intgemm_8bit_shifted.sh b/tests/decoder/intgemm/_test_intgemm_8bit_shifted.sh
index 1782f35..cd33092 100644
--- a/tests/decoder/intgemm/_test_intgemm_8bit_shifted.sh
+++ b/tests/decoder/intgemm/_test_intgemm_8bit_shifted.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_16bit.sh b/tests/decoder/intgemm/test_intgemm_16bit.sh
index 89ad809..4b21c02 100644
--- a/tests/decoder/intgemm/test_intgemm_16bit.sh
+++ b/tests/decoder/intgemm/test_intgemm_16bit.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_16bit_avx2.sh b/tests/decoder/intgemm/test_intgemm_16bit_avx2.sh
index f918767..a22faea 100644
--- a/tests/decoder/intgemm/test_intgemm_16bit_avx2.sh
+++ b/tests/decoder/intgemm/test_intgemm_16bit_avx2.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx2" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_16bit_sse2.sh b/tests/decoder/intgemm/test_intgemm_16bit_sse2.sh
index afdef7a..cf38314 100644
--- a/tests/decoder/intgemm/test_intgemm_16bit_sse2.sh
+++ b/tests/decoder/intgemm/test_intgemm_16bit_sse2.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "sse2" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_8bit.sh b/tests/decoder/intgemm/test_intgemm_8bit.sh
index d6098a0..861d6d4 100644
--- a/tests/decoder/intgemm/test_intgemm_8bit.sh
+++ b/tests/decoder/intgemm/test_intgemm_8bit.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_8bit_avx2.sh b/tests/decoder/intgemm/test_intgemm_8bit_avx2.sh
index a42dd6f..0ad812d 100644
--- a/tests/decoder/intgemm/test_intgemm_8bit_avx2.sh
+++ b/tests/decoder/intgemm/test_intgemm_8bit_avx2.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "avx2" /proc/cpuinfo; then
diff --git a/tests/decoder/intgemm/test_intgemm_8bit_ssse3.sh b/tests/decoder/intgemm/test_intgemm_8bit_ssse3.sh
index 565e18d..7044550 100644
--- a/tests/decoder/intgemm/test_intgemm_8bit_ssse3.sh
+++ b/tests/decoder/intgemm/test_intgemm_8bit_ssse3.sh
@@ -9,7 +9,7 @@
set -e
# Skip if requirements are not met
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+if [ ! $MRT_MARIAN_USE_CPU ]; then
echo "Marian is not compiled with CPU" 1>&2
exit 100
elif ! grep -q "ssse3" /proc/cpuinfo; then
diff --git a/tests/decoder/align/test_align_cpu.sh b/tests/decoder/align/test_align_cpu.sh
index 7870bc4..a77eb7b 100644
--- a/tests/decoder/align/test_align_cpu.sh
+++ b/tests/decoder/align/test_align_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/decoder/wmt16/test_ende_cpu.sh b/tests/decoder/wmt16/test_ende_cpu.sh
index 145ff3e..35afe5c 100644
--- a/tests/decoder/wmt16/test_ende_cpu.sh
+++ b/tests/decoder/wmt16/test_ende_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/models/transformer/test_hard_aligns_cpu.sh b/tests/models/transformer/test_hard_aligns_cpu.sh
index cc1a48c..6140773 100644
--- a/tests/models/transformer/test_hard_aligns_cpu.sh
+++ b/tests/models/transformer/test_hard_aligns_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/models/wnmt18/test_student_small.sh b/tests/models/wnmt18/test_student_small.sh
index e5c2765..f365011 100644
--- a/tests/models/wnmt18/test_student_small.sh
+++ b/tests/models/wnmt18/test_student_small.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/models/wnmt18/test_student_small_aan.sh b/tests/models/wnmt18/test_student_small_aan.sh
index 9eb023e..c3f492e 100644
--- a/tests/models/wnmt18/test_student_small_aan.sh
+++ b/tests/models/wnmt18/test_student_small_aan.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/models/wnmt18/test_student_small_aan_intgemm16.sh b/tests/models/wnmt18/test_student_small_aan_intgemm16.sh
index e08e5de..ad88e9c 100644
--- a/tests/models/wnmt18/test_student_small_aan_intgemm16.sh
+++ b/tests/models/wnmt18/test_student_small_aan_intgemm16.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/models/wnmt18/test_student_small_aan_intgemm8.sh b/tests/models/wnmt18/test_student_small_aan_intgemm8.sh
index 44bd527..4f3aef7 100644
--- a/tests/models/wnmt18/test_student_small_aan_intgemm8.sh
+++ b/tests/models/wnmt18/test_student_small_aan_intgemm8.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/scorer/scores/test_scores_cpu.sh b/tests/scorer/scores/test_scores_cpu.sh
index 2c69898..e19cc5d 100644
--- a/tests/scorer/scores/test_scores_cpu.sh
+++ b/tests/scorer/scores/test_scores_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/server/test_ende_cpu.sh b/tests/server/test_ende_cpu.sh
index 2cef7c2..74bffb8 100644
--- a/tests/server/test_ende_cpu.sh
+++ b/tests/server/test_ende_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi
diff --git a/tests/training/restoring/multi-gpu/test_adam_sync_cpu.sh b/tests/training/restoring/multi-gpu/test_adam_sync_cpu.sh
index fcfdcd5..3998f19 100644
--- a/tests/training/restoring/multi-gpu/test_adam_sync_cpu.sh
+++ b/tests/training/restoring/multi-gpu/test_adam_sync_cpu.sh
@@ -8,8 +8,8 @@
# Exit on error
set -e
-# Skip if no MKL found
-if [ ! $MRT_MARIAN_USE_MKL ]; then
+# Skip if no CPU found
+if [ ! $MRT_MARIAN_USE_CPU ]; then
exit 100
fi